@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2015 Red Hat, Inc.
 # All Rights Reserved.
 #
@@ -17,10 +15,10 @@
 
 import mock
 
+from ironic_lib import disk_utils
 from oslo_concurrency import processutils
 from oslotest import base as test_base
 
-from ironic_lib import disk_utils
 from ironic_python_agent import errors
 from ironic_python_agent.extensions import iscsi
 from ironic_python_agent import hardware
@@ -33,8 +31,8 @@ class FakeAgent(object):
 
 
 @mock.patch.object(disk_utils, 'destroy_disk_metadata', autospec=True)
-@mock.patch.object(hardware, 'dispatch_to_managers')
-@mock.patch.object(utils, 'execute')
+@mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
+@mock.patch.object(utils, 'execute', autospec=True)
 @mock.patch.object(iscsi.rtslib_fb, 'RTSRoot',
                    mock.Mock(side_effect=iscsi.rtslib_fb.RTSLibError()))
 class TestISCSIExtensionTgt(test_base.BaseTestCase):
@@ -118,7 +116,7 @@ class TestISCSIExtensionTgt(test_base.BaseTestCase):
         mock_dispatch.assert_called_once_with('get_os_install_device')
         self.assertFalse(mock_destroy.called)
 
-    @mock.patch.object(iscsi, '_wait_for_tgtd')
+    @mock.patch.object(iscsi, '_wait_for_tgtd', autospec=True)
     def test_start_iscsi_target_fail_command(self, mock_wait_iscsi,
                                              mock_execute, mock_dispatch,
                                              mock_destroy):
@@ -141,9 +139,9 @@ _ORIG_UTILS = iscsi.rtslib_fb.utils
 
 
 @mock.patch.object(disk_utils, 'destroy_disk_metadata', autospec=True)
-@mock.patch.object(hardware, 'dispatch_to_managers')
+@mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
 # Don't mock the utils module, as it contains exceptions
-@mock.patch.object(iscsi, 'rtslib_fb', utils=_ORIG_UTILS)
+@mock.patch.object(iscsi, 'rtslib_fb', utils=_ORIG_UTILS, autospec=True)
 class TestISCSIExtensionLIO(test_base.BaseTestCase):
 
     def setUp(self):
@@ -152,8 +150,37 @@ class TestISCSIExtensionLIO(test_base.BaseTestCase):
         self.fake_dev = '/dev/fake'
         self.fake_iqn = 'iqn-fake'
 
-    def test_start_iscsi_target(self, mock_rtslib, mock_dispatch,
+    @mock.patch('ironic_python_agent.netutils.get_wildcard_address',
+                autospec=True)
+    def test_start_iscsi_target(self, mock_get_wildcard_address,
+                                mock_rtslib, mock_dispatch,
                                 mock_destroy):
+        mock_get_wildcard_address.return_value = '::'
+        mock_dispatch.return_value = self.fake_dev
+        result = self.agent_extension.start_iscsi_target(iqn=self.fake_iqn)
+
+        self.assertEqual({'iscsi_target_iqn': self.fake_iqn},
+                         result.command_result)
+        mock_rtslib.BlockStorageObject.assert_called_once_with(
+            name=self.fake_iqn, dev=self.fake_dev)
+        mock_rtslib.Target.assert_called_once_with(mock.ANY, self.fake_iqn,
+                                                   mode='create')
+        mock_rtslib.TPG.assert_called_once_with(
+            mock_rtslib.Target.return_value, mode='create')
+        mock_rtslib.LUN.assert_called_once_with(
+            mock_rtslib.TPG.return_value,
+            storage_object=mock_rtslib.BlockStorageObject.return_value,
+            lun=1)
+        mock_rtslib.NetworkPortal.assert_called_once_with(
+            mock_rtslib.TPG.return_value, '[::]', 3260)
+        self.assertFalse(mock_destroy.called)
+
+    @mock.patch('ironic_python_agent.netutils.get_wildcard_address',
+                autospec=True)
+    def test_start_iscsi_target_noipv6(self, mock_get_wildcard_address,
+                                       mock_rtslib, mock_dispatch,
+                                       mock_destroy):
+        mock_get_wildcard_address.return_value = '0.0.0.0'
         mock_dispatch.return_value = self.fake_dev
         result = self.agent_extension.start_iscsi_target(iqn=self.fake_iqn)
 
@@ -173,9 +200,13 @@ class TestISCSIExtensionLIO(test_base.BaseTestCase):
             mock_rtslib.TPG.return_value, '0.0.0.0', 3260)
         self.assertFalse(mock_destroy.called)
 
-    def test_start_iscsi_target_with_special_port(self, mock_rtslib,
-                                                  mock_dispatch,
+    @mock.patch('ironic_python_agent.netutils.get_wildcard_address',
+                autospec=True)
+    def test_start_iscsi_target_with_special_port(self,
+                                                  mock_get_wildcard_address,
+                                                  mock_rtslib, mock_dispatch,
                                                   mock_destroy):
+        mock_get_wildcard_address.return_value = '::'
         mock_dispatch.return_value = self.fake_dev
         result = self.agent_extension.start_iscsi_target(iqn=self.fake_iqn,
                                                          portal_port=3266)
@@ -193,7 +224,7 @@ class TestISCSIExtensionLIO(test_base.BaseTestCase):
             storage_object=mock_rtslib.BlockStorageObject.return_value,
             lun=1)
         mock_rtslib.NetworkPortal.assert_called_once_with(
-            mock_rtslib.TPG.return_value, '0.0.0.0', 3266)
+            mock_rtslib.TPG.return_value, '[::]', 3266)
 
     def test_failed_to_start_iscsi(self, mock_rtslib, mock_dispatch,
                                    mock_destroy):
@@ -203,8 +234,11 @@ class TestISCSIExtensionLIO(test_base.BaseTestCase):
             errors.ISCSIError, 'Failed to create a target',
             self.agent_extension.start_iscsi_target, iqn=self.fake_iqn)
 
-    def test_failed_to_bind_iscsi(self, mock_rtslib, mock_dispatch,
-                                  mock_destroy):
+    @mock.patch('ironic_python_agent.netutils.get_wildcard_address',
+                autospec=True)
+    def test_failed_to_bind_iscsi(self, mock_get_wildcard_address,
+                                  mock_rtslib, mock_dispatch, mock_destroy):
+        mock_get_wildcard_address.return_value = '::'
         mock_dispatch.return_value = self.fake_dev
         mock_rtslib.NetworkPortal.side_effect = _ORIG_UTILS.RTSLibError()
         self.assertRaisesRegex(
@@ -223,7 +257,7 @@ class TestISCSIExtensionLIO(test_base.BaseTestCase):
             storage_object=mock_rtslib.BlockStorageObject.return_value,
             lun=1)
         mock_rtslib.NetworkPortal.assert_called_once_with(
-            mock_rtslib.TPG.return_value, '0.0.0.0', 3260)
+            mock_rtslib.TPG.return_value, '[::]', 3260)
         self.assertFalse(mock_destroy.called)
 
     def test_failed_to_start_iscsi_wipe_disk_metadata(self, mock_rtslib,
@@ -239,7 +273,7 @@ class TestISCSIExtensionLIO(test_base.BaseTestCase):
         mock_destroy.assert_called_once_with('/dev/fake', 'my_node_uuid')
 
 
-@mock.patch.object(iscsi.rtslib_fb, 'RTSRoot')
+@mock.patch.object(iscsi.rtslib_fb, 'RTSRoot', autospec=True)
 class TestISCSIExtensionCleanUp(test_base.BaseTestCase):
 
     def setUp(self):
